@@ -160,3 +160,66 @@ class Audience(Base):
 
     # Номер аудитории (На английском))
     number_en = Column('audience_number_en', String)
+
+
+class Citizenship(Base):
+    """
+    Гражданство
+    """
+    __tablename__ = 'univer_citizenship_1c'
+
+    # Идентификатор
+    id = Column('citizenship_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('citizenship_name_ru', String(500))
+    name_kz = Column('citizenship_name_kz', String(500))
+    name_en = Column('citizenship_name_en', String(500))
+
+    # Короткое наименование
+    short_name_ru = Column('citizenship_short_name_ru', String(500))
+    short_name_kz = Column('citizenship_short_name_kz', String(500))
+    short_name_en = Column('citizenship_short_name_en', String(500))
+
+    # ISO-коды
+    code = Column('citizenship_code', Integer)
+    code2 = Column('citizenship_code2', String(250))
+    code3 = Column('citizenship_code3', String(250))
+
+    # Статус
+    status = Column(Integer)
+
+    def __repr__(self):
+        return '<Citizenship {} (id={} code2={} status={})>'.format(self, self.id, self.code2, self.status)
+
+    def __str__(self):
+        return self.name_ru
+
+
+class Nationality(Base):
+    """
+    Национальность
+    """
+    __tablename__ = 'univer_nationality'
+
+    # Идентификатор
+    id = Column('nationality_id', Integer, primary_key=True)
+
+    # Статус
+    status = Column(Integer)
+
+    # Наименование
+    name_ru = Column('nationality_name_ru', String(100))
+    name_kz = Column('nationality_name_kz', String(100))
+    name_en = Column('nationality_name_en', String(100))
+
+    # Короткое наименование
+    short_name_ru = Column('nationality_short_name_ru', String(20))
+    short_name_kz = Column('nationality_short_name_kz', String(20))
+    short_name_en = Column('nationality_short_name_en', String(20))
+
+    def __repr__(self):
+        return '<Nationality {} (id={} status={})>'.format(self, self.id, self.status)
+
+    def __str__(self):
+        return self.name_ru
