@@ -156,6 +156,14 @@ class Student(Base):
     speciality_id = Column(ForeignKey('univer_speciality.speciality_id'))
     speciality = relationship('Speciality')
 
+    # Гражданство
+    citizenship_id = Column(ForeignKey('univer_citizenship_1c.citizenship_id'))
+    citizenship = relationship('Citizenship')
+
+    # Национальность
+    nationality_id = Column(ForeignKey('univer_nationality.nationality_id'))
+    nationality = relationship('Nationality')
+
     # Год начала действия учебного плана
     educ_plan_adm_year = Column(Integer)
 
@@ -445,12 +453,16 @@ class AdviserStudent(Base):
     __tablename__ = 'univer_advicer_student_link'
 
     # Эдвайзер
-    adviser_id = Column('advicer_id', ForeignKey('univer_advicer.advicer_id'), primary_key=True)
-    adviser = relationship('Adviser', backref=backref('students', lazy='dynamic'))
+    adviser_id = Column('advicer_id', ForeignKey(
+        'univer_advicer.advicer_id'), primary_key=True)
+    adviser = relationship(
+        'Adviser', backref=backref('students', lazy='dynamic'))
 
     # Студент
-    student_id = Column(ForeignKey('univer_students.students_id'), primary_key=True)
-    student = relationship('Student', backref=backref('advisers', lazy='dynamic'))
+    student_id = Column(ForeignKey(
+        'univer_students.students_id'), primary_key=True)
+    student = relationship(
+        'Student', backref=backref('advisers', lazy='dynamic'))
 
     def __repr__(self):
         return '<AdviserStudent {}>'.format(self)
